# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class Relationship(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cardinality': 'str',
        'description': 'str',
        'display_name': 'str',
        'field_definitions': 'list[FieldDefinition]',
        'relationship_id': 'str',
        'target': 'str'
    }

    attribute_map = {
        'cardinality': 'cardinality',
        'description': 'description',
        'display_name': 'displayName',
        'field_definitions': 'fieldDefinitions',
        'relationship_id': 'relationshipId',
        'target': 'target'
    }

    def __init__(self, cardinality=None, description=None, display_name=None, field_definitions=None, relationship_id=None, target=None, local_vars_configuration=None):  # noqa: E501
        """Relationship - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cardinality = None
        self._description = None
        self._display_name = None
        self._field_definitions = None
        self._relationship_id = None
        self._target = None
        self.discriminator = None

        if cardinality is not None:
            self.cardinality = cardinality
        if description is not None:
            self.description = description
        if display_name is not None:
            self.display_name = display_name
        if field_definitions is not None:
            self.field_definitions = field_definitions
        if relationship_id is not None:
            self.relationship_id = relationship_id
        if target is not None:
            self.target = target

    @property
    def cardinality(self):
        """Gets the cardinality of this Relationship.  # noqa: E501


        :return: The cardinality of this Relationship.  # noqa: E501
        :rtype: str
        """
        return self._cardinality

    @cardinality.setter
    def cardinality(self, cardinality):
        """Sets the cardinality of this Relationship.


        :param cardinality: The cardinality of this Relationship.  # noqa: E501
        :type: str
        """

        self._cardinality = cardinality

    @property
    def description(self):
        """Gets the description of this Relationship.  # noqa: E501


        :return: The description of this Relationship.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Relationship.


        :param description: The description of this Relationship.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def display_name(self):
        """Gets the display_name of this Relationship.  # noqa: E501


        :return: The display_name of this Relationship.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this Relationship.


        :param display_name: The display_name of this Relationship.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def field_definitions(self):
        """Gets the field_definitions of this Relationship.  # noqa: E501


        :return: The field_definitions of this Relationship.  # noqa: E501
        :rtype: list[FieldDefinition]
        """
        return self._field_definitions

    @field_definitions.setter
    def field_definitions(self, field_definitions):
        """Sets the field_definitions of this Relationship.


        :param field_definitions: The field_definitions of this Relationship.  # noqa: E501
        :type: list[FieldDefinition]
        """

        self._field_definitions = field_definitions

    @property
    def relationship_id(self):
        """Gets the relationship_id of this Relationship.  # noqa: E501


        :return: The relationship_id of this Relationship.  # noqa: E501
        :rtype: str
        """
        return self._relationship_id

    @relationship_id.setter
    def relationship_id(self, relationship_id):
        """Sets the relationship_id of this Relationship.


        :param relationship_id: The relationship_id of this Relationship.  # noqa: E501
        :type: str
        """

        self._relationship_id = relationship_id

    @property
    def target(self):
        """Gets the target of this Relationship.  # noqa: E501


        :return: The target of this Relationship.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this Relationship.


        :param target: The target of this Relationship.  # noqa: E501
        :type: str
        """

        self._target = target

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Relationship):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Relationship):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pycherwell
from pycherwell.api.service_api import ServiceApi  # noqa: E501
from pycherwell.rest import ApiException


class TestServiceApi(unittest.TestCase):
    """ServiceApi unit test stubs"""

    def setUp(self):
        self.api = pycherwell.api.service_api.ServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_service_get_service_info_v1(self):
        """Test case for service_get_service_info_v1

        Get information about the REST Api and CSM  # noqa: E501
        """
        pass

    def test_service_logout_user_v1(self):
        """Test case for service_logout_user_v1

        Log out user by token  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class Right(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'add': 'bool',
        'allow': 'bool',
        'category_description': 'str',
        'category_id': 'str',
        'category_name': 'str',
        'delete': 'bool',
        'edit': 'bool',
        'is_yes_no_right': 'bool',
        'non_scope_owner_add': 'bool',
        'non_scope_owner_delete': 'bool',
        'non_scope_owner_edit': 'bool',
        'non_scope_owner_view': 'bool',
        'right_id': 'str',
        'right_name': 'str',
        'standard_right_name': 'str',
        'view_run_open': 'bool'
    }

    attribute_map = {
        'add': 'add',
        'allow': 'allow',
        'category_description': 'categoryDescription',
        'category_id': 'categoryId',
        'category_name': 'categoryName',
        'delete': 'delete',
        'edit': 'edit',
        'is_yes_no_right': 'isYesNoRight',
        'non_scope_owner_add': 'nonScopeOwnerAdd',
        'non_scope_owner_delete': 'nonScopeOwnerDelete',
        'non_scope_owner_edit': 'nonScopeOwnerEdit',
        'non_scope_owner_view': 'nonScopeOwnerView',
        'right_id': 'rightId',
        'right_name': 'rightName',
        'standard_right_name': 'standardRightName',
        'view_run_open': 'viewRunOpen'
    }

    def __init__(self, add=None, allow=None, category_description=None, category_id=None, category_name=None, delete=None, edit=None, is_yes_no_right=None, non_scope_owner_add=None, non_scope_owner_delete=None, non_scope_owner_edit=None, non_scope_owner_view=None, right_id=None, right_name=None, standard_right_name=None, view_run_open=None, local_vars_configuration=None):  # noqa: E501
        """Right - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._add = None
        self._allow = None
        self._category_description = None
        self._category_id = None
        self._category_name = None
        self._delete = None
        self._edit = None
        self._is_yes_no_right = None
        self._non_scope_owner_add = None
        self._non_scope_owner_delete = None
        self._non_scope_owner_edit = None
        self._non_scope_owner_view = None
        self._right_id = None
        self._right_name = None
        self._standard_right_name = None
        self._view_run_open = None
        self.discriminator = None

        if add is not None:
            self.add = add
        if allow is not None:
            self.allow = allow
        if category_description is not None:
            self.category_description = category_description
        if category_id is not None:
            self.category_id = category_id
        if category_name is not None:
            self.category_name = category_name
        if delete is not None:
            self.delete = delete
        if edit is not None:
            self.edit = edit
        if is_yes_no_right is not None:
            self.is_yes_no_right = is_yes_no_right
        if non_scope_owner_add is not None:
            self.non_scope_owner_add = non_scope_owner_add
        if non_scope_owner_delete is not None:
            self.non_scope_owner_delete = non_scope_owner_delete
        if non_scope_owner_edit is not None:
            self.non_scope_owner_edit = non_scope_owner_edit
        if non_scope_owner_view is not None:
            self.non_scope_owner_view = non_scope_owner_view
        if right_id is not None:
            self.right_id = right_id
        if right_name is not None:
            self.right_name = right_name
        if standard_right_name is not None:
            self.standard_right_name = standard_right_name
        if view_run_open is not None:
            self.view_run_open = view_run_open

    @property
    def add(self):
        """Gets the add of this Right.  # noqa: E501


        :return: The add of this Right.  # noqa: E501
        :rtype: bool
        """
        return self._add

    @add.setter
    def add(self, add):
        """Sets the add of this Right.


        :param add: The add of this Right.  # noqa: E501
        :type: bool
        """

        self._add = add

    @property
    def allow(self):
        """Gets the allow of this Right.  # noqa: E501


        :return: The allow of this Right.  # noqa: E501
        :rtype: bool
        """
        return self._allow

    @allow.setter
    def allow(self, allow):
        """Sets the allow of this Right.


        :param allow: The allow of this Right.  # noqa: E501
        :type: bool
        """

        self._allow = allow

    @property
    def category_description(self):
        """Gets the category_description of this Right.  # noqa: E501


        :return: The category_description of this Right.  # noqa: E501
        :rtype: str
        """
        return self._category_description

    @category_description.setter
    def category_description(self, category_description):
        """Sets the category_description of this Right.


        :param category_description: The category_description of this Right.  # noqa: E501
        :type: str
        """

        self._category_description = category_description

    @property
    def category_id(self):
        """Gets the category_id of this Right.  # noqa: E501


        :return: The category_id of this Right.  # noqa: E501
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this Right.


        :param category_id: The category_id of this Right.  # noqa: E501
        :type: str
        """

        self._category_id = category_id

    @property
    def category_name(self):
        """Gets the category_name of this Right.  # noqa: E501


        :return: The category_name of this Right.  # noqa: E501
        :rtype: str
        """
        return self._category_name

    @category_name.setter
    def category_name(self, category_name):
        """Sets the category_name of this Right.


        :param category_name: The category_name of this Right.  # noqa: E501
        :type: str
        """

        self._category_name = category_name

    @property
    def delete(self):
        """Gets the delete of this Right.  # noqa: E501


        :return: The delete of this Right.  # noqa: E501
        :rtype: bool
        """
        return self._delete

    @delete.setter
    def delete(self, delete):
        """Sets the delete of this Right.


        :param delete: The delete of this Right.  # noqa: E501
        :type: bool
        """

        self._delete = delete

    @property
    def edit(self):
        """Gets the edit of this Right.  # noqa: E501


        :return: The edit of this Right.  # noqa: E501
        :rtype: bool
        """
        return self._edit

    @edit.setter
    def edit(self, edit):
        """Sets the edit of this Right.


        :param edit: The edit of this Right.  # noqa: E501
        :type: bool
        """

        self._edit = edit

    @property
    def is_yes_no_right(self):
        """Gets the is_yes_no_right of this Right.  # noqa: E501


        :return: The is_yes_no_right of this Right.  # noqa: E501
        :rtype: bool
        """
        return self._is_yes_no_right

    @is_yes_no_right.setter
    def is_yes_no_right(self, is_yes_no_right):
        """Sets the is_yes_no_right of this Right.


        :param is_yes_no_right: The is_yes_no_right of this Right.  # noqa: E501
        :type: bool
        """

        self._is_yes_no_right = is_yes_no_right

    @property
    def non_scope_owner_add(self):
        """Gets the non_scope_owner_add of this Right.  # noqa: E501


        :return: The non_scope_owner_add of this Right.  # noqa: E501
        :rtype: bool
        """
        return self._non_scope_owner_add

    @non_scope_owner_add.setter
    def non_scope_owner_add(self, non_scope_owner_add):
        """Sets the non_scope_owner_add of this Right.


        :param non_scope_owner_add: The non_scope_owner_add of this Right.  # noqa: E501
        :type: bool
        """

        self._non_scope_owner_add = non_scope_owner_add

    @property
    def non_scope_owner_delete(self):
        """Gets the non_scope_owner_delete of this Right.  # noqa: E501


        :return: The non_scope_owner_delete of this Right.  # noqa: E501
        :rtype: bool
        """
        return self._non_scope_owner_delete

    @non_scope_owner_delete.setter
    def non_scope_owner_delete(self, non_scope_owner_delete):
        """Sets the non_scope_owner_delete of this Right.


        :param non_scope_owner_delete: The non_scope_owner_delete of this Right.  # noqa: E501
        :type: bool
        """

        self._non_scope_owner_delete = non_scope_owner_delete

    @property
    def non_scope_owner_edit(self):
        """Gets the non_scope_owner_edit of this Right.  # noqa: E501


        :return: The non_scope_owner_edit of this Right.  # noqa: E501
        :rtype: bool
        """
        return self._non_scope_owner_edit

    @non_scope_owner_edit.setter
    def non_scope_owner_edit(self, non_scope_owner_edit):
        """Sets the non_scope_owner_edit of this Right.


        :param non_scope_owner_edit: The non_scope_owner_edit of this Right.  # noqa: E501
        :type: bool
        """

        self._non_scope_owner_edit = non_scope_owner_edit

    @property
    def non_scope_owner_view(self):
        """Gets the non_scope_owner_view of this Right.  # noqa: E501


        :return: The non_scope_owner_view of this Right.  # noqa: E501
        :rtype: bool
        """
        return self._non_scope_owner_view

    @non_scope_owner_view.setter
    def non_scope_owner_view(self, non_scope_owner_view):
        """Sets the non_scope_owner_view of this Right.


        :param non_scope_owner_view: The non_scope_owner_view of this Right.  # noqa: E501
        :type: bool
        """

        self._non_scope_owner_view = non_scope_owner_view

    @property
    def right_id(self):
        """Gets the right_id of this Right.  # noqa: E501


        :return: The right_id of this Right.  # noqa: E501
        :rtype: str
        """
        return self._right_id

    @right_id.setter
    def right_id(self, right_id):
        """Sets the right_id of this Right.


        :param right_id: The right_id of this Right.  # noqa: E501
        :type: str
        """

        self._right_id = right_id

    @property
    def right_name(self):
        """Gets the right_name of this Right.  # noqa: E501


        :return: The right_name of this Right.  # noqa: E501
        :rtype: str
        """
        return self._right_name

    @right_name.setter
    def right_name(self, right_name):
        """Sets the right_name of this Right.


        :param right_name: The right_name of this Right.  # noqa: E501
        :type: str
        """

        self._right_name = right_name

    @property
    def standard_right_name(self):
        """Gets the standard_right_name of this Right.  # noqa: E501


        :return: The standard_right_name of this Right.  # noqa: E501
        :rtype: str
        """
        return self._standard_right_name

    @standard_right_name.setter
    def standard_right_name(self, standard_right_name):
        """Sets the standard_right_name of this Right.


        :param standard_right_name: The standard_right_name of this Right.  # noqa: E501
        :type: str
        """

        self._standard_right_name = standard_right_name

    @property
    def view_run_open(self):
        """Gets the view_run_open of this Right.  # noqa: E501


        :return: The view_run_open of this Right.  # noqa: E501
        :rtype: bool
        """
        return self._view_run_open

    @view_run_open.setter
    def view_run_open(self, view_run_open):
        """Sets the view_run_open of this Right.


        :param view_run_open: The view_run_open of this Right.  # noqa: E501
        :type: bool
        """

        self._view_run_open = view_run_open

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Right):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Right):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pycherwell
from pycherwell.api.searches_api import SearchesApi  # noqa: E501
from pycherwell.rest import ApiException


class TestSearchesApi(unittest.TestCase):
    """SearchesApi unit test stubs"""

    def setUp(self):
        self.api = pycherwell.api.searches_api.SearchesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_searches_get_quick_search_configuration_for_bus_obs_v1(self):
        """Test case for searches_get_quick_search_configuration_for_bus_obs_v1

        Get a Quick Search from a list of Business Object IDs  # noqa: E501
        """
        pass

    def test_searches_get_quick_search_configuration_for_bus_obs_with_view_rights_v1(self):
        """Test case for searches_get_quick_search_configuration_for_bus_obs_with_view_rights_v1

        Get a Quick Search by Business Objects with view rights  # noqa: E501
        """
        pass

    def test_searches_get_quick_search_results_v1(self):
        """Test case for searches_get_quick_search_results_v1

        Execute a Quick Search from a list of Business Object IDs and search text  # noqa: E501
        """
        pass

    def test_searches_get_quick_search_specific_results_v1(self):
        """Test case for searches_get_quick_search_specific_results_v1

        Execute a Quick Search on a specific Business Object  # noqa: E501
        """
        pass

    def test_searches_get_quick_search_specific_results_v2(self):
        """Test case for searches_get_quick_search_specific_results_v2

        Execute a Quick Search on a specific Business Object  # noqa: E501
        """
        pass

    def test_searches_get_search_items_by_association_scope_scope_owner_folder_v1(self):
        """Test case for searches_get_search_items_by_association_scope_scope_owner_folder_v1

        Get all saved searches by Folder ID  # noqa: E501
        """
        pass

    def test_searches_get_search_items_by_association_scope_scope_owner_folder_v2(self):
        """Test case for searches_get_search_items_by_association_scope_scope_owner_folder_v2

        Get all saved searches by Folder ID  # noqa: E501
        """
        pass

    def test_searches_get_search_items_by_association_scope_scope_owner_v1(self):
        """Test case for searches_get_search_items_by_association_scope_scope_owner_v1

        Get all saved searches by scope owner (sub scope)  # noqa: E501
        """
        pass

    def test_searches_get_search_items_by_association_scope_scope_owner_v2(self):
        """Test case for searches_get_search_items_by_association_scope_scope_owner_v2

        Get all saved searches by scope owner (sub scope)  # noqa: E501
        """
        pass

    def test_searches_get_search_items_by_association_scope_v1(self):
        """Test case for searches_get_search_items_by_association_scope_v1

        Get all saved searches by scope  # noqa: E501
        """
        pass

    def test_searches_get_search_items_by_association_scope_v2(self):
        """Test case for searches_get_search_items_by_association_scope_v2

        Get all saved searches by scope  # noqa: E501
        """
        pass

    def test_searches_get_search_items_by_association_v1(self):
        """Test case for searches_get_search_items_by_association_v1

        Get all saved searches by Business Object association  # noqa: E501
        """
        pass

    def test_searches_get_search_items_by_association_v2(self):
        """Test case for searches_get_search_items_by_association_v2

        Get all saved searches by Business Object association  # noqa: E501
        """
        pass

    def test_searches_get_search_items_v1(self):
        """Test case for searches_get_search_items_v1

        Get all saved searches by default Business Object association  # noqa: E501
        """
        pass

    def test_searches_get_search_items_v2(self):
        """Test case for searches_get_search_items_v2

        Get all saved searches by default Business Object association  # noqa: E501
        """
        pass

    def test_searches_get_search_results_ad_hoc_v1(self):
        """Test case for searches_get_search_results_ad_hoc_v1

        Run an ad-hoc search  # noqa: E501
        """
        pass

    def test_searches_get_search_results_by_id_v1(self):
        """Test case for searches_get_search_results_by_id_v1

        Run a saved search by internal ID  # noqa: E501
        """
        pass

    def test_searches_get_search_results_by_name_v1(self):
        """Test case for searches_get_search_results_by_name_v1

        Run a saved search by name  # noqa: E501
        """
        pass

    def test_searches_get_search_results_export_ad_hoc_v1(self):
        """Test case for searches_get_search_results_export_ad_hoc_v1

        Export an ad-hoc search  # noqa: E501
        """
        pass

    def test_searches_get_search_results_export_by_id_v1(self):
        """Test case for searches_get_search_results_export_by_id_v1

        Export a saved search by ID  # noqa: E501
        """
        pass

    def test_searches_get_search_results_export_by_name_v1(self):
        """Test case for searches_get_search_results_export_by_name_v1

        Export a saved search by name  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pycherwell
from pycherwell.api.forms_api import FormsApi  # noqa: E501
from pycherwell.rest import ApiException


class TestFormsApi(unittest.TestCase):
    """FormsApi unit test stubs"""

    def setUp(self):
        self.api = pycherwell.api.forms_api.FormsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_forms_get_mobile_form_for_bus_ob_by_id_and_public_id_v1(self):
        """Test case for forms_get_mobile_form_for_bus_ob_by_id_and_public_id_v1

        Get mobile form by BusObId and Public ID  # noqa: E501
        """
        pass

    def test_forms_get_mobile_form_for_bus_ob_by_id_and_rec_id_v1(self):
        """Test case for forms_get_mobile_form_for_bus_ob_by_id_and_rec_id_v1

        Get mobile form by Business Object ID and Business Object Record ID.  # noqa: E501
        """
        pass

    def test_forms_get_mobile_form_for_bus_ob_by_name_and_public_id_v1(self):
        """Test case for forms_get_mobile_form_for_bus_ob_by_name_and_public_id_v1

        Get mobile form by Business Object name and Public ID  # noqa: E501
        """
        pass

    def test_forms_get_mobile_form_for_bus_ob_by_name_and_rec_id_v1(self):
        """Test case for forms_get_mobile_form_for_bus_ob_by_name_and_rec_id_v1

        Get mobile form by Business Object name and record ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class SchemaResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bus_ob_id': 'str',
        'field_definitions': 'list[FieldDefinition]',
        'first_rec_id_field': 'str',
        'grid_definitions': 'list[GridDefinition]',
        'name': 'str',
        'rec_id_fields': 'str',
        'relationships': 'list[Relationship]',
        'state_field_id': 'str',
        'states': 'str',
        'error_code': 'str',
        'error_message': 'str',
        'has_error': 'bool'
    }

    attribute_map = {
        'bus_ob_id': 'busObId',
        'field_definitions': 'fieldDefinitions',
        'first_rec_id_field': 'firstRecIdField',
        'grid_definitions': 'gridDefinitions',
        'name': 'name',
        'rec_id_fields': 'recIdFields',
        'relationships': 'relationships',
        'state_field_id': 'stateFieldId',
        'states': 'states',
        'error_code': 'errorCode',
        'error_message': 'errorMessage',
        'has_error': 'hasError'
    }

    def __init__(self, bus_ob_id=None, field_definitions=None, first_rec_id_field=None, grid_definitions=None, name=None, rec_id_fields=None, relationships=None, state_field_id=None, states=None, error_code=None, error_message=None, has_error=None, local_vars_configuration=None):  # noqa: E501
        """SchemaResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bus_ob_id = None
        self._field_definitions = None
        self._first_rec_id_field = None
        self._grid_definitions = None
        self._name = None
        self._rec_id_fields = None
        self._relationships = None
        self._state_field_id = None
        self._states = None
        self._error_code = None
        self._error_message = None
        self._has_error = None
        self.discriminator = None

        if bus_ob_id is not None:
            self.bus_ob_id = bus_ob_id
        if field_definitions is not None:
            self.field_definitions = field_definitions
        if first_rec_id_field is not None:
            self.first_rec_id_field = first_rec_id_field
        if grid_definitions is not None:
            self.grid_definitions = grid_definitions
        if name is not None:
            self.name = name
        if rec_id_fields is not None:
            self.rec_id_fields = rec_id_fields
        if relationships is not None:
            self.relationships = relationships
        if state_field_id is not None:
            self.state_field_id = state_field_id
        if states is not None:
            self.states = states
        if error_code is not None:
            self.error_code = error_code
        if error_message is not None:
            self.error_message = error_message
        if has_error is not None:
            self.has_error = has_error

    @property
    def bus_ob_id(self):
        """Gets the bus_ob_id of this SchemaResponse.  # noqa: E501


        :return: The bus_ob_id of this SchemaResponse.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_id

    @bus_ob_id.setter
    def bus_ob_id(self, bus_ob_id):
        """Sets the bus_ob_id of this SchemaResponse.


        :param bus_ob_id: The bus_ob_id of this SchemaResponse.  # noqa: E501
        :type: str
        """

        self._bus_ob_id = bus_ob_id

    @property
    def field_definitions(self):
        """Gets the field_definitions of this SchemaResponse.  # noqa: E501


        :return: The field_definitions of this SchemaResponse.  # noqa: E501
        :rtype: list[FieldDefinition]
        """
        return self._field_definitions

    @field_definitions.setter
    def field_definitions(self, field_definitions):
        """Sets the field_definitions of this SchemaResponse.


        :param field_definitions: The field_definitions of this SchemaResponse.  # noqa: E501
        :type: list[FieldDefinition]
        """

        self._field_definitions = field_definitions

    @property
    def first_rec_id_field(self):
        """Gets the first_rec_id_field of this SchemaResponse.  # noqa: E501


        :return: The first_rec_id_field of this SchemaResponse.  # noqa: E501
        :rtype: str
        """
        return self._first_rec_id_field

    @first_rec_id_field.setter
    def first_rec_id_field(self, first_rec_id_field):
        """Sets the first_rec_id_field of this SchemaResponse.


        :param first_rec_id_field: The first_rec_id_field of this SchemaResponse.  # noqa: E501
        :type: str
        """

        self._first_rec_id_field = first_rec_id_field

    @property
    def grid_definitions(self):
        """Gets the grid_definitions of this SchemaResponse.  # noqa: E501


        :return: The grid_definitions of this SchemaResponse.  # noqa: E501
        :rtype: list[GridDefinition]
        """
        return self._grid_definitions

    @grid_definitions.setter
    def grid_definitions(self, grid_definitions):
        """Sets the grid_definitions of this SchemaResponse.


        :param grid_definitions: The grid_definitions of this SchemaResponse.  # noqa: E501
        :type: list[GridDefinition]
        """

        self._grid_definitions = grid_definitions

    @property
    def name(self):
        """Gets the name of this SchemaResponse.  # noqa: E501


        :return: The name of this SchemaResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SchemaResponse.


        :param name: The name of this SchemaResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def rec_id_fields(self):
        """Gets the rec_id_fields of this SchemaResponse.  # noqa: E501


        :return: The rec_id_fields of this SchemaResponse.  # noqa: E501
        :rtype: str
        """
        return self._rec_id_fields

    @rec_id_fields.setter
    def rec_id_fields(self, rec_id_fields):
        """Sets the rec_id_fields of this SchemaResponse.


        :param rec_id_fields: The rec_id_fields of this SchemaResponse.  # noqa: E501
        :type: str
        """

        self._rec_id_fields = rec_id_fields

    @property
    def relationships(self):
        """Gets the relationships of this SchemaResponse.  # noqa: E501


        :return: The relationships of this SchemaResponse.  # noqa: E501
        :rtype: list[Relationship]
        """
        return self._relationships

    @relationships.setter
    def relationships(self, relationships):
        """Sets the relationships of this SchemaResponse.


        :param relationships: The relationships of this SchemaResponse.  # noqa: E501
        :type: list[Relationship]
        """

        self._relationships = relationships

    @property
    def state_field_id(self):
        """Gets the state_field_id of this SchemaResponse.  # noqa: E501


        :return: The state_field_id of this SchemaResponse.  # noqa: E501
        :rtype: str
        """
        return self._state_field_id

    @state_field_id.setter
    def state_field_id(self, state_field_id):
        """Sets the state_field_id of this SchemaResponse.


        :param state_field_id: The state_field_id of this SchemaResponse.  # noqa: E501
        :type: str
        """

        self._state_field_id = state_field_id

    @property
    def states(self):
        """Gets the states of this SchemaResponse.  # noqa: E501


        :return: The states of this SchemaResponse.  # noqa: E501
        :rtype: str
        """
        return self._states

    @states.setter
    def states(self, states):
        """Sets the states of this SchemaResponse.


        :param states: The states of this SchemaResponse.  # noqa: E501
        :type: str
        """

        self._states = states

    @property
    def error_code(self):
        """Gets the error_code of this SchemaResponse.  # noqa: E501


        :return: The error_code of this SchemaResponse.  # noqa: E501
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this SchemaResponse.


        :param error_code: The error_code of this SchemaResponse.  # noqa: E501
        :type: str
        """

        self._error_code = error_code

    @property
    def error_message(self):
        """Gets the error_message of this SchemaResponse.  # noqa: E501


        :return: The error_message of this SchemaResponse.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this SchemaResponse.


        :param error_message: The error_message of this SchemaResponse.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def has_error(self):
        """Gets the has_error of this SchemaResponse.  # noqa: E501


        :return: The has_error of this SchemaResponse.  # noqa: E501
        :rtype: bool
        """
        return self._has_error

    @has_error.setter
    def has_error(self, has_error):
        """Sets the has_error of this SchemaResponse.


        :param has_error: The has_error of this SchemaResponse.  # noqa: E501
        :type: bool
        """

        self._has_error = has_error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SchemaResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SchemaResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pycherwell
from pycherwell.api.security_api import SecurityApi  # noqa: E501
from pycherwell.rest import ApiException


class TestSecurityApi(unittest.TestCase):
    """SecurityApi unit test stubs"""

    def setUp(self):
        self.api = pycherwell.api.security_api.SecurityApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_security_get_client_security_settings_v1(self):
        """Test case for security_get_client_security_settings_v1

        Get client security settings  # noqa: E501
        """
        pass

    def test_security_get_roles_v1(self):
        """Test case for security_get_roles_v1

        Get all available Roles  # noqa: E501
        """
        pass

    def test_security_get_roles_v2(self):
        """Test case for security_get_roles_v2

        Get all available Roles  # noqa: E501
        """
        pass

    def test_security_get_security_group_business_object_permissions_by_bus_ob_id_v1(self):
        """Test case for security_get_security_group_business_object_permissions_by_bus_ob_id_v1

        Get Business Object permissions by Security Group  # noqa: E501
        """
        pass

    def test_security_get_security_group_business_object_permissions_by_bus_ob_id_v2(self):
        """Test case for security_get_security_group_business_object_permissions_by_bus_ob_id_v2

        Get Business Object permissions by Security Group  # noqa: E501
        """
        pass

    def test_security_get_security_group_business_object_permissions_by_bus_ob_name_v1(self):
        """Test case for security_get_security_group_business_object_permissions_by_bus_ob_name_v1

        Get Business Object permissions by Security Group  # noqa: E501
        """
        pass

    def test_security_get_security_group_business_object_permissions_by_bus_ob_name_v2(self):
        """Test case for security_get_security_group_business_object_permissions_by_bus_ob_name_v2

        Get Business Object permissions by Security Group  # noqa: E501
        """
        pass

    def test_security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v1(self):
        """Test case for security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v1

        Get Business Object permission for current user  # noqa: E501
        """
        pass

    def test_security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v2(self):
        """Test case for security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_id_v2

        Get Business Object permission for current user  # noqa: E501
        """
        pass

    def test_security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v1(self):
        """Test case for security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v1

        Get Business Object permissions for current user  # noqa: E501
        """
        pass

    def test_security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v2(self):
        """Test case for security_get_security_group_business_object_permissions_for_current_user_by_bus_ob_name_v2

        Get Business Object permissions for current user  # noqa: E501
        """
        pass

    def test_security_get_security_group_categories_v1(self):
        """Test case for security_get_security_group_categories_v1

        Get all Security Group categories  # noqa: E501
        """
        pass

    def test_security_get_security_group_categories_v2(self):
        """Test case for security_get_security_group_categories_v2

        Get all Security Group categories  # noqa: E501
        """
        pass

    def test_security_get_security_group_rights_by_group_id_and_category_id_v1(self):
        """Test case for security_get_security_group_rights_by_group_id_and_category_id_v1

        Get permissions for a Security Group by category  # noqa: E501
        """
        pass

    def test_security_get_security_group_rights_by_group_id_and_category_id_v2(self):
        """Test case for security_get_security_group_rights_by_group_id_and_category_id_v2

        Get permissions for a Security Group by category  # noqa: E501
        """
        pass

    def test_security_get_security_group_rights_by_group_name_and_category_name_v1(self):
        """Test case for security_get_security_group_rights_by_group_name_and_category_name_v1

        Get permissions for a Security Group by category  # noqa: E501
        """
        pass

    def test_security_get_security_group_rights_by_group_name_and_category_name_v2(self):
        """Test case for security_get_security_group_rights_by_group_name_and_category_name_v2

        Get permissions for a Security Group by category  # noqa: E501
        """
        pass

    def test_security_get_security_group_rights_for_current_user_by_category_id_v1(self):
        """Test case for security_get_security_group_rights_for_current_user_by_category_id_v1

        Get current user's permissions by Security Group category by ID  # noqa: E501
        """
        pass

    def test_security_get_security_group_rights_for_current_user_by_category_id_v2(self):
        """Test case for security_get_security_group_rights_for_current_user_by_category_id_v2

        Get current user's permissions by Security Group category by ID  # noqa: E501
        """
        pass

    def test_security_get_security_group_rights_for_current_user_by_category_name_v1(self):
        """Test case for security_get_security_group_rights_for_current_user_by_category_name_v1

        Get current user's permissions by Security Group category by name  # noqa: E501
        """
        pass

    def test_security_get_security_group_rights_for_current_user_by_category_name_v2(self):
        """Test case for security_get_security_group_rights_for_current_user_by_category_name_v2

        Get current user's permissions by Security Group category by name  # noqa: E501
        """
        pass

    def test_security_get_security_groups_v1(self):
        """Test case for security_get_security_groups_v1

        Get all available Security Groups  # noqa: E501
        """
        pass

    def test_security_get_security_groups_v2(self):
        """Test case for security_get_security_groups_v2

        Get all available Security Groups  # noqa: E501
        """
        pass

    def test_security_get_users_in_security_group_v1(self):
        """Test case for security_get_users_in_security_group_v1

        Get users in a Security Group  # noqa: E501
        """
        pass

    def test_security_get_users_in_security_group_v2(self):
        """Test case for security_get_users_in_security_group_v2

        Get users in a Security Group  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pycherwell.api_client import ApiClient
from pycherwell.exceptions import (
    ApiTypeError,
    ApiValueError
)


class QueuesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def queues_add_item_to_queue_v1(self, add_item_to_queue_request, **kwargs):  # noqa: E501
        """Add a Business Object to a queue  # noqa: E501

        Operation to add a Business Object to a queue  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.queues_add_item_to_queue_v1(add_item_to_queue_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddItemToQueueRequest add_item_to_queue_request: Request object containing all properties necessary to add an item to a queue. All properties are required. The standin key defines the queue to which we want to add the Business Object. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AddItemToQueueResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.queues_add_item_to_queue_v1_with_http_info(add_item_to_queue_request, **kwargs)  # noqa: E501

    def queues_add_item_to_queue_v1_with_http_info(self, add_item_to_queue_request, **kwargs):  # noqa: E501
        """Add a Business Object to a queue  # noqa: E501

        Operation to add a Business Object to a queue  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.queues_add_item_to_queue_v1_with_http_info(add_item_to_queue_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddItemToQueueRequest add_item_to_queue_request: Request object containing all properties necessary to add an item to a queue. All properties are required. The standin key defines the queue to which we want to add the Business Object. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AddItemToQueueResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['add_item_to_queue_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method queues_add_item_to_queue_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'add_item_to_queue_request' is set
        if self.api_client.client_side_validation and ('add_item_to_queue_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['add_item_to_queue_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `add_item_to_queue_request` when calling `queues_add_item_to_queue_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_item_to_queue_request' in local_var_params:
            body_params = local_var_params['add_item_to_queue_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/additemtoqueue', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AddItemToQueueResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def queues_check_in_queue_item_v1(self, check_in_queue_item_request, **kwargs):  # noqa: E501
        """Check a Business Object in to a queue  # noqa: E501

        Operation to check in a queue item  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.queues_check_in_queue_item_v1(check_in_queue_item_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CheckInQueueItemRequest check_in_queue_item_request: The request object for checking in an item to a queue. All properties are required except for historyNotes (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CheckInQueueItemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.queues_check_in_queue_item_v1_with_http_info(check_in_queue_item_request, **kwargs)  # noqa: E501

    def queues_check_in_queue_item_v1_with_http_info(self, check_in_queue_item_request, **kwargs):  # noqa: E501
        """Check a Business Object in to a queue  # noqa: E501

        Operation to check in a queue item  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.queues_check_in_queue_item_v1_with_http_info(check_in_queue_item_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CheckInQueueItemRequest check_in_queue_item_request: The request object for checking in an item to a queue. All properties are required except for historyNotes (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CheckInQueueItemResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['check_in_queue_item_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method queues_check_in_queue_item_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'check_in_queue_item_request' is set
        if self.api_client.client_side_validation and ('check_in_queue_item_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['check_in_queue_item_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `check_in_queue_item_request` when calling `queues_check_in_queue_item_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'check_in_queue_item_request' in local_var_params:
            body_params = local_var_params['check_in_queue_item_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/checkinqueueitem', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CheckInQueueItemResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def queues_check_out_queue_item_v1(self, check_out_queue_item_request, **kwargs):  # noqa: E501
        """Check a Business Object out of a queue  # noqa: E501

        Operation to check out a queue item  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.queues_check_out_queue_item_v1(check_out_queue_item_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CheckOutQueueItemRequest check_out_queue_item_request: The request object for checking out an item from a queue. All properties are required except for historyNotes (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CheckOutQueueItemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.queues_check_out_queue_item_v1_with_http_info(check_out_queue_item_request, **kwargs)  # noqa: E501

    def queues_check_out_queue_item_v1_with_http_info(self, check_out_queue_item_request, **kwargs):  # noqa: E501
        """Check a Business Object out of a queue  # noqa: E501

        Operation to check out a queue item  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.queues_check_out_queue_item_v1_with_http_info(check_out_queue_item_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CheckOutQueueItemRequest check_out_queue_item_request: The request object for checking out an item from a queue. All properties are required except for historyNotes (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CheckOutQueueItemResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['check_out_queue_item_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method queues_check_out_queue_item_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'check_out_queue_item_request' is set
        if self.api_client.client_side_validation and ('check_out_queue_item_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['check_out_queue_item_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `check_out_queue_item_request` when calling `queues_check_out_queue_item_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'check_out_queue_item_request' in local_var_params:
            body_params = local_var_params['check_out_queue_item_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/checkoutqueueitem', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CheckOutQueueItemResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def queues_get_queues_folder_v1(self, scope, scopeowner, folder, **kwargs):  # noqa: E501
        """Get available queues.  # noqa: E501

        Get available queues for a specific Business Object type based on scope, scope owner, and folder.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.queues_get_queues_folder_v1(scope, scopeowner, folder, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope to get available queues for. (required)
        :param str scopeowner: The scope owner to get available queues for. (required)
        :param str folder: The folder to get available queues for. (required)
        :param bool links: Whether or not to include links.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.queues_get_queues_folder_v1_with_http_info(scope, scopeowner, folder, **kwargs)  # noqa: E501

    def queues_get_queues_folder_v1_with_http_info(self, scope, scopeowner, folder, **kwargs):  # noqa: E501
        """Get available queues.  # noqa: E501

        Get available queues for a specific Business Object type based on scope, scope owner, and folder.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.queues_get_queues_folder_v1_with_http_info(scope, scopeowner, folder, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope to get available queues for. (required)
        :param str scopeowner: The scope owner to get available queues for. (required)
        :param str folder: The folder to get available queues for. (required)
        :param bool links: Whether or not to include links.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['scope', 'scopeowner', 'folder', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method queues_get_queues_folder_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `queues_get_queues_folder_v1`")  # noqa: E501
        # verify the required parameter 'scopeowner' is set
        if self.api_client.client_side_validation and ('scopeowner' not in local_var_params or  # noqa: E501
                                                        local_var_params['scopeowner'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scopeowner` when calling `queues_get_queues_folder_v1`")  # noqa: E501
        # verify the required parameter 'folder' is set
        if self.api_client.client_side_validation and ('folder' not in local_var_params or  # noqa: E501
                                                        local_var_params['folder'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder` when calling `queues_get_queues_folder_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501
        if 'scopeowner' in local_var_params:
            path_params['scopeowner'] = local_var_params['scopeowner']  # noqa: E501
        if 'folder' in local_var_params:
            path_params['folder'] = local_var_params['folder']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getqueues/scope/{scope}/scopeowner/{scopeowner}/folder/{folder}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def queues_get_queues_scope_owner_v1(self, scope, scopeowner, **kwargs):  # noqa: E501
        """Get available queues.  # noqa: E501

        Get available queues for a specific Business Object type based on scope, and scope owner.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.queues_get_queues_scope_owner_v1(scope, scopeowner, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope to get available queues for. (required)
        :param str scopeowner: The scope owner to get available queues for. (required)
        :param bool links: Whether or not to include links.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.queues_get_queues_scope_owner_v1_with_http_info(scope, scopeowner, **kwargs)  # noqa: E501

    def queues_get_queues_scope_owner_v1_with_http_info(self, scope, scopeowner, **kwargs):  # noqa: E501
        """Get available queues.  # noqa: E501

        Get available queues for a specific Business Object type based on scope, and scope owner.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.queues_get_queues_scope_owner_v1_with_http_info(scope, scopeowner, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope to get available queues for. (required)
        :param str scopeowner: The scope owner to get available queues for. (required)
        :param bool links: Whether or not to include links.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['scope', 'scopeowner', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method queues_get_queues_scope_owner_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `queues_get_queues_scope_owner_v1`")  # noqa: E501
        # verify the required parameter 'scopeowner' is set
        if self.api_client.client_side_validation and ('scopeowner' not in local_var_params or  # noqa: E501
                                                        local_var_params['scopeowner'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scopeowner` when calling `queues_get_queues_scope_owner_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501
        if 'scopeowner' in local_var_params:
            path_params['scopeowner'] = local_var_params['scopeowner']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getqueues/scope/{scope}/scopeowner/{scopeowner}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def queues_get_queues_scope_v1(self, scope, **kwargs):  # noqa: E501
        """Get available queues.  # noqa: E501

        Get available queues for a specific Business Object type based on scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.queues_get_queues_scope_v1(scope, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope to get available queues for. (required)
        :param bool links: Whether or not to include links.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.queues_get_queues_scope_v1_with_http_info(scope, **kwargs)  # noqa: E501

    def queues_get_queues_scope_v1_with_http_info(self, scope, **kwargs):  # noqa: E501
        """Get available queues.  # noqa: E501

        Get available queues for a specific Business Object type based on scope.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.queues_get_queues_scope_v1_with_http_info(scope, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scope: The scope to get available queues for. (required)
        :param bool links: Whether or not to include links.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['scope', 'links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method queues_get_queues_scope_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scope' is set
        if self.api_client.client_side_validation and ('scope' not in local_var_params or  # noqa: E501
                                                        local_var_params['scope'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scope` when calling `queues_get_queues_scope_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'scope' in local_var_params:
            path_params['scope'] = local_var_params['scope']  # noqa: E501

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getqueues/scope/{scope}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def queues_get_queues_v1(self, **kwargs):  # noqa: E501
        """Get available queues.  # noqa: E501

        Get available queues for a specific Business Object.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.queues_get_queues_v1(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool links: Whether or not to include links.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ManagerData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.queues_get_queues_v1_with_http_info(**kwargs)  # noqa: E501

    def queues_get_queues_v1_with_http_info(self, **kwargs):  # noqa: E501
        """Get available queues.  # noqa: E501

        Get available queues for a specific Business Object.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.queues_get_queues_v1_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool links: Whether or not to include links.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ManagerData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['links']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method queues_get_queues_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'links' in local_var_params and local_var_params['links'] is not None:  # noqa: E501
            query_params.append(('links', local_var_params['links']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/getqueues', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ManagerData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def queues_remove_item_from_queue_v1(self, remove_item_from_queue_request, **kwargs):  # noqa: E501
        """Remove an item from a queue  # noqa: E501

        Operation to remove an item from a queue  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.queues_remove_item_from_queue_v1(remove_item_from_queue_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param RemoveItemFromQueueRequest remove_item_from_queue_request: The request object to remove an item from a queue. All properties are required except for historyNotes (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RemoveItemFromQueueResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.queues_remove_item_from_queue_v1_with_http_info(remove_item_from_queue_request, **kwargs)  # noqa: E501

    def queues_remove_item_from_queue_v1_with_http_info(self, remove_item_from_queue_request, **kwargs):  # noqa: E501
        """Remove an item from a queue  # noqa: E501

        Operation to remove an item from a queue  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.queues_remove_item_from_queue_v1_with_http_info(remove_item_from_queue_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param RemoveItemFromQueueRequest remove_item_from_queue_request: The request object to remove an item from a queue. All properties are required except for historyNotes (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RemoveItemFromQueueResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['remove_item_from_queue_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method queues_remove_item_from_queue_v1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'remove_item_from_queue_request' is set
        if self.api_client.client_side_validation and ('remove_item_from_queue_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['remove_item_from_queue_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `remove_item_from_queue_request` when calling `queues_remove_item_from_queue_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'remove_item_from_queue_request' in local_var_params:
            body_params = local_var_params['remove_item_from_queue_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/V1/removeitemfromqueue', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RemoveItemFromQueueResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pycherwell
from pycherwell.api.business_object_api import BusinessObjectApi  # noqa: E501
from pycherwell.rest import ApiException


class TestBusinessObjectApi(unittest.TestCase):
    """BusinessObjectApi unit test stubs"""

    def setUp(self):
        self.api = pycherwell.api.business_object_api.BusinessObjectApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_object_delete_business_object_batch_v1(self):
        """Test case for business_object_delete_business_object_batch_v1

        Delete Business Objects in a batch  # noqa: E501
        """
        pass

    def test_business_object_delete_business_object_by_public_id_v1(self):
        """Test case for business_object_delete_business_object_by_public_id_v1

        Delete a Business Object by public ID  # noqa: E501
        """
        pass

    def test_business_object_delete_business_object_by_rec_id_v1(self):
        """Test case for business_object_delete_business_object_by_rec_id_v1

        Delete a Business Object by record ID  # noqa: E501
        """
        pass

    def test_business_object_delete_related_business_object_by_public_id_v1(self):
        """Test case for business_object_delete_related_business_object_by_public_id_v1

        Delete a related Business Object by public ID  # noqa: E501
        """
        pass

    def test_business_object_delete_related_business_object_by_rec_id_v1(self):
        """Test case for business_object_delete_related_business_object_by_rec_id_v1

        Delete a related Business Object by record ID  # noqa: E501
        """
        pass

    def test_business_object_field_values_lookup_v1(self):
        """Test case for business_object_field_values_lookup_v1

        Get lookup values for fields  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_attachment_by_attachment_id_v1(self):
        """Test case for business_object_get_business_object_attachment_by_attachment_id_v1

        Get an imported Business Object attachment  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_attachments_by_id_and_public_id_v1(self):
        """Test case for business_object_get_business_object_attachments_by_id_and_public_id_v1

        Get attachments by Business Object public ID  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_attachments_by_id_and_rec_id_v1(self):
        """Test case for business_object_get_business_object_attachments_by_id_and_rec_id_v1

        Get attachments by Business Object record ID  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_attachments_by_name_and_public_id_v1(self):
        """Test case for business_object_get_business_object_attachments_by_name_and_public_id_v1

        Get attachments by Business Object name and public ID  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_attachments_by_name_and_rec_id_v1(self):
        """Test case for business_object_get_business_object_attachments_by_name_and_rec_id_v1

        Get attachments by Business Object name and record ID  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_attachments_v1(self):
        """Test case for business_object_get_business_object_attachments_v1

        Get Business Object attachments by request object  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_batch_v1(self):
        """Test case for business_object_get_business_object_batch_v1

        Get a batch of Business Object records  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_by_public_id_v1(self):
        """Test case for business_object_get_business_object_by_public_id_v1

        Get a Business Object record  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_by_rec_id_v1(self):
        """Test case for business_object_get_business_object_by_rec_id_v1

        Get a Business Object record  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_by_scan_code_bus_ob_id_v1(self):
        """Test case for business_object_get_business_object_by_scan_code_bus_ob_id_v1

        Get a Business Object by its scan code and Business Object ID  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_by_scan_code_bus_ob_name_v1(self):
        """Test case for business_object_get_business_object_by_scan_code_bus_ob_name_v1

        Get a Business Object by its scan code and Business Object name  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_schema_v1(self):
        """Test case for business_object_get_business_object_schema_v1

        Get a Business Object schema  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_summaries_v1(self):
        """Test case for business_object_get_business_object_summaries_v1

        Get Business Object summaries by type  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_summary_by_id_v1(self):
        """Test case for business_object_get_business_object_summary_by_id_v1

        Get a Business Object summary by ID  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_summary_by_name_v1(self):
        """Test case for business_object_get_business_object_summary_by_name_v1

        Get a Business Object summary by name  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_template_v1(self):
        """Test case for business_object_get_business_object_template_v1

        Get Business Object templates for create  # noqa: E501
        """
        pass

    def test_business_object_get_related_business_object_by_request_v1(self):
        """Test case for business_object_get_related_business_object_by_request_v1

        Get related Business Objects using a request object  # noqa: E501
        """
        pass

    def test_business_object_get_related_business_object_v1(self):
        """Test case for business_object_get_related_business_object_v1

        Get related Business Objects by ID  # noqa: E501
        """
        pass

    def test_business_object_get_related_business_object_with_custom_grid_v1(self):
        """Test case for business_object_get_related_business_object_with_custom_grid_v1

        Get related Business Objects custom grid  # noqa: E501
        """
        pass

    def test_business_object_link_related_business_object_by_rec_id_v1(self):
        """Test case for business_object_link_related_business_object_by_rec_id_v1

        Link related Business Objects  # noqa: E501
        """
        pass

    def test_business_object_remove_business_object_attachment_by_id_and_public_id_v1(self):
        """Test case for business_object_remove_business_object_attachment_by_id_and_public_id_v1

        Remove an attachment by Business Object ID and public ID  # noqa: E501
        """
        pass

    def test_business_object_remove_business_object_attachment_by_id_and_rec_id_v1(self):
        """Test case for business_object_remove_business_object_attachment_by_id_and_rec_id_v1

        Remove an attachment by Business Object ID and record ID  # noqa: E501
        """
        pass

    def test_business_object_remove_business_object_attachment_by_name_and_public_id_v1(self):
        """Test case for business_object_remove_business_object_attachment_by_name_and_public_id_v1

        Remove an attachment by Business Object name and public ID  # noqa: E501
        """
        pass

    def test_business_object_remove_business_object_attachment_by_name_and_rec_id_v1(self):
        """Test case for business_object_remove_business_object_attachment_by_name_and_rec_id_v1

        Remove an attachment by Business Object name and record ID  # noqa: E501
        """
        pass

    def test_business_object_save_business_object_attachment_bus_ob_v1(self):
        """Test case for business_object_save_business_object_attachment_bus_ob_v1

        Attach a Business Object to a Business Object  # noqa: E501
        """
        pass

    def test_business_object_save_business_object_attachment_link_v1(self):
        """Test case for business_object_save_business_object_attachment_link_v1

        Attach a file via UNC  # noqa: E501
        """
        pass

    def test_business_object_save_business_object_attachment_url_v1(self):
        """Test case for business_object_save_business_object_attachment_url_v1

        Attach a URL path  # noqa: E501
        """
        pass

    def test_business_object_save_business_object_batch_v1(self):
        """Test case for business_object_save_business_object_batch_v1

        Create or update a batch of Business Objects  # noqa: E501
        """
        pass

    def test_business_object_save_business_object_v1(self):
        """Test case for business_object_save_business_object_v1

        Create or Update a Business Object  # noqa: E501
        """
        pass

    def test_business_object_save_related_business_object_v1(self):
        """Test case for business_object_save_related_business_object_v1

        Create or update a related Business Object  # noqa: E501
        """
        pass

    def test_business_object_un_link_related_business_object_by_rec_id_v1(self):
        """Test case for business_object_un_link_related_business_object_by_rec_id_v1

        UnLink related Business Objects  # noqa: E501
        """
        pass

    def test_business_object_upload_business_object_attachment_by_id_and_public_id_v1(self):
        """Test case for business_object_upload_business_object_attachment_by_id_and_public_id_v1

        Upload an attachment by Business Object ID and public ID  # noqa: E501
        """
        pass

    def test_business_object_upload_business_object_attachment_by_id_and_rec_id_v1(self):
        """Test case for business_object_upload_business_object_attachment_by_id_and_rec_id_v1

        Upload an attachment by Business Object ID and record ID  # noqa: E501
        """
        pass

    def test_business_object_upload_business_object_attachment_by_name_and_public_id_v1(self):
        """Test case for business_object_upload_business_object_attachment_by_name_and_public_id_v1

        Upload an attachment by Business Object name and public ID  # noqa: E501
        """
        pass

    def test_business_object_upload_business_object_attachment_by_name_and_rec_id_v1(self):
        """Test case for business_object_upload_business_object_attachment_by_name_and_rec_id_v1

        Upload an attachment by Business Object name and record ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class QuickSearchSpecificByIdRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bus_ob_ids': 'list[str]',
        'stand_in': 'str',
        'ascending': 'bool',
        'non_final_state': 'bool',
        'search_any_words': 'bool',
        'search_attachments': 'bool',
        'search_related': 'bool',
        'search_text': 'str',
        'selected_changed_limit': 'ChangedLimit',
        'selected_sort_by_field_id': 'str',
        'use_sort_by': 'bool',
        'specific_search_target_id': 'str',
        'is_bus_ob_target': 'bool'
    }

    attribute_map = {
        'bus_ob_ids': 'busObIds',
        'stand_in': 'standIn',
        'ascending': 'ascending',
        'non_final_state': 'nonFinalState',
        'search_any_words': 'searchAnyWords',
        'search_attachments': 'searchAttachments',
        'search_related': 'searchRelated',
        'search_text': 'searchText',
        'selected_changed_limit': 'selectedChangedLimit',
        'selected_sort_by_field_id': 'selectedSortByFieldId',
        'use_sort_by': 'useSortBy',
        'specific_search_target_id': 'specificSearchTargetId',
        'is_bus_ob_target': 'isBusObTarget'
    }

    def __init__(self, bus_ob_ids=None, stand_in=None, ascending=None, non_final_state=None, search_any_words=None, search_attachments=None, search_related=None, search_text=None, selected_changed_limit=None, selected_sort_by_field_id=None, use_sort_by=None, specific_search_target_id=None, is_bus_ob_target=None, local_vars_configuration=None):  # noqa: E501
        """QuickSearchSpecificByIdRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bus_ob_ids = None
        self._stand_in = None
        self._ascending = None
        self._non_final_state = None
        self._search_any_words = None
        self._search_attachments = None
        self._search_related = None
        self._search_text = None
        self._selected_changed_limit = None
        self._selected_sort_by_field_id = None
        self._use_sort_by = None
        self._specific_search_target_id = None
        self._is_bus_ob_target = None
        self.discriminator = None

        if bus_ob_ids is not None:
            self.bus_ob_ids = bus_ob_ids
        if stand_in is not None:
            self.stand_in = stand_in
        if ascending is not None:
            self.ascending = ascending
        if non_final_state is not None:
            self.non_final_state = non_final_state
        if search_any_words is not None:
            self.search_any_words = search_any_words
        if search_attachments is not None:
            self.search_attachments = search_attachments
        if search_related is not None:
            self.search_related = search_related
        if search_text is not None:
            self.search_text = search_text
        if selected_changed_limit is not None:
            self.selected_changed_limit = selected_changed_limit
        if selected_sort_by_field_id is not None:
            self.selected_sort_by_field_id = selected_sort_by_field_id
        if use_sort_by is not None:
            self.use_sort_by = use_sort_by
        if specific_search_target_id is not None:
            self.specific_search_target_id = specific_search_target_id
        if is_bus_ob_target is not None:
            self.is_bus_ob_target = is_bus_ob_target

    @property
    def bus_ob_ids(self):
        """Gets the bus_ob_ids of this QuickSearchSpecificByIdRequest.  # noqa: E501


        :return: The bus_ob_ids of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._bus_ob_ids

    @bus_ob_ids.setter
    def bus_ob_ids(self, bus_ob_ids):
        """Sets the bus_ob_ids of this QuickSearchSpecificByIdRequest.


        :param bus_ob_ids: The bus_ob_ids of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :type: list[str]
        """

        self._bus_ob_ids = bus_ob_ids

    @property
    def stand_in(self):
        """Gets the stand_in of this QuickSearchSpecificByIdRequest.  # noqa: E501


        :return: The stand_in of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :rtype: str
        """
        return self._stand_in

    @stand_in.setter
    def stand_in(self, stand_in):
        """Sets the stand_in of this QuickSearchSpecificByIdRequest.


        :param stand_in: The stand_in of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :type: str
        """

        self._stand_in = stand_in

    @property
    def ascending(self):
        """Gets the ascending of this QuickSearchSpecificByIdRequest.  # noqa: E501


        :return: The ascending of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :rtype: bool
        """
        return self._ascending

    @ascending.setter
    def ascending(self, ascending):
        """Sets the ascending of this QuickSearchSpecificByIdRequest.


        :param ascending: The ascending of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :type: bool
        """

        self._ascending = ascending

    @property
    def non_final_state(self):
        """Gets the non_final_state of this QuickSearchSpecificByIdRequest.  # noqa: E501


        :return: The non_final_state of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :rtype: bool
        """
        return self._non_final_state

    @non_final_state.setter
    def non_final_state(self, non_final_state):
        """Sets the non_final_state of this QuickSearchSpecificByIdRequest.


        :param non_final_state: The non_final_state of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :type: bool
        """

        self._non_final_state = non_final_state

    @property
    def search_any_words(self):
        """Gets the search_any_words of this QuickSearchSpecificByIdRequest.  # noqa: E501


        :return: The search_any_words of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :rtype: bool
        """
        return self._search_any_words

    @search_any_words.setter
    def search_any_words(self, search_any_words):
        """Sets the search_any_words of this QuickSearchSpecificByIdRequest.


        :param search_any_words: The search_any_words of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :type: bool
        """

        self._search_any_words = search_any_words

    @property
    def search_attachments(self):
        """Gets the search_attachments of this QuickSearchSpecificByIdRequest.  # noqa: E501


        :return: The search_attachments of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :rtype: bool
        """
        return self._search_attachments

    @search_attachments.setter
    def search_attachments(self, search_attachments):
        """Sets the search_attachments of this QuickSearchSpecificByIdRequest.


        :param search_attachments: The search_attachments of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :type: bool
        """

        self._search_attachments = search_attachments

    @property
    def search_related(self):
        """Gets the search_related of this QuickSearchSpecificByIdRequest.  # noqa: E501


        :return: The search_related of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :rtype: bool
        """
        return self._search_related

    @search_related.setter
    def search_related(self, search_related):
        """Sets the search_related of this QuickSearchSpecificByIdRequest.


        :param search_related: The search_related of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :type: bool
        """

        self._search_related = search_related

    @property
    def search_text(self):
        """Gets the search_text of this QuickSearchSpecificByIdRequest.  # noqa: E501


        :return: The search_text of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :rtype: str
        """
        return self._search_text

    @search_text.setter
    def search_text(self, search_text):
        """Sets the search_text of this QuickSearchSpecificByIdRequest.


        :param search_text: The search_text of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :type: str
        """

        self._search_text = search_text

    @property
    def selected_changed_limit(self):
        """Gets the selected_changed_limit of this QuickSearchSpecificByIdRequest.  # noqa: E501


        :return: The selected_changed_limit of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :rtype: ChangedLimit
        """
        return self._selected_changed_limit

    @selected_changed_limit.setter
    def selected_changed_limit(self, selected_changed_limit):
        """Sets the selected_changed_limit of this QuickSearchSpecificByIdRequest.


        :param selected_changed_limit: The selected_changed_limit of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :type: ChangedLimit
        """

        self._selected_changed_limit = selected_changed_limit

    @property
    def selected_sort_by_field_id(self):
        """Gets the selected_sort_by_field_id of this QuickSearchSpecificByIdRequest.  # noqa: E501


        :return: The selected_sort_by_field_id of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :rtype: str
        """
        return self._selected_sort_by_field_id

    @selected_sort_by_field_id.setter
    def selected_sort_by_field_id(self, selected_sort_by_field_id):
        """Sets the selected_sort_by_field_id of this QuickSearchSpecificByIdRequest.


        :param selected_sort_by_field_id: The selected_sort_by_field_id of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :type: str
        """

        self._selected_sort_by_field_id = selected_sort_by_field_id

    @property
    def use_sort_by(self):
        """Gets the use_sort_by of this QuickSearchSpecificByIdRequest.  # noqa: E501


        :return: The use_sort_by of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :rtype: bool
        """
        return self._use_sort_by

    @use_sort_by.setter
    def use_sort_by(self, use_sort_by):
        """Sets the use_sort_by of this QuickSearchSpecificByIdRequest.


        :param use_sort_by: The use_sort_by of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :type: bool
        """

        self._use_sort_by = use_sort_by

    @property
    def specific_search_target_id(self):
        """Gets the specific_search_target_id of this QuickSearchSpecificByIdRequest.  # noqa: E501


        :return: The specific_search_target_id of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :rtype: str
        """
        return self._specific_search_target_id

    @specific_search_target_id.setter
    def specific_search_target_id(self, specific_search_target_id):
        """Sets the specific_search_target_id of this QuickSearchSpecificByIdRequest.


        :param specific_search_target_id: The specific_search_target_id of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :type: str
        """

        self._specific_search_target_id = specific_search_target_id

    @property
    def is_bus_ob_target(self):
        """Gets the is_bus_ob_target of this QuickSearchSpecificByIdRequest.  # noqa: E501


        :return: The is_bus_ob_target of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_bus_ob_target

    @is_bus_ob_target.setter
    def is_bus_ob_target(self, is_bus_ob_target):
        """Sets the is_bus_ob_target of this QuickSearchSpecificByIdRequest.


        :param is_bus_ob_target: The is_bus_ob_target of this QuickSearchSpecificByIdRequest.  # noqa: E501
        :type: bool
        """

        self._is_bus_ob_target = is_bus_ob_target

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QuickSearchSpecificByIdRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QuickSearchSpecificByIdRequest):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from pycherwell.api.business_object_api import BusinessObjectApi
from pycherwell.api.core_api import CoreApi
from pycherwell.api.forms_api import FormsApi
from pycherwell.api.queues_api import QueuesApi
from pycherwell.api.searches_api import SearchesApi
from pycherwell.api.security_api import SecurityApi
from pycherwell.api.service_api import ServiceApi
from pycherwell.api.teams_api import TeamsApi
from pycherwell.api.users_api import UsersApi



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class ViewSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'group_summaries': 'list[ViewSummary]',
        'image': 'str',
        'is_part_of_view': 'bool',
        'bus_ob_id': 'str',
        'display_name': 'str',
        'group': 'bool',
        'lookup': 'bool',
        'major': 'bool',
        'name': 'str',
        'supporting': 'bool'
    }

    attribute_map = {
        'group_summaries': 'groupSummaries',
        'image': 'image',
        'is_part_of_view': 'isPartOfView',
        'bus_ob_id': 'busObId',
        'display_name': 'displayName',
        'group': 'group',
        'lookup': 'lookup',
        'major': 'major',
        'name': 'name',
        'supporting': 'supporting'
    }

    def __init__(self, group_summaries=None, image=None, is_part_of_view=None, bus_ob_id=None, display_name=None, group=None, lookup=None, major=None, name=None, supporting=None, local_vars_configuration=None):  # noqa: E501
        """ViewSummary - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._group_summaries = None
        self._image = None
        self._is_part_of_view = None
        self._bus_ob_id = None
        self._display_name = None
        self._group = None
        self._lookup = None
        self._major = None
        self._name = None
        self._supporting = None
        self.discriminator = None

        if group_summaries is not None:
            self.group_summaries = group_summaries
        if image is not None:
            self.image = image
        if is_part_of_view is not None:
            self.is_part_of_view = is_part_of_view
        if bus_ob_id is not None:
            self.bus_ob_id = bus_ob_id
        if display_name is not None:
            self.display_name = display_name
        if group is not None:
            self.group = group
        if lookup is not None:
            self.lookup = lookup
        if major is not None:
            self.major = major
        if name is not None:
            self.name = name
        if supporting is not None:
            self.supporting = supporting

    @property
    def group_summaries(self):
        """Gets the group_summaries of this ViewSummary.  # noqa: E501


        :return: The group_summaries of this ViewSummary.  # noqa: E501
        :rtype: list[ViewSummary]
        """
        return self._group_summaries

    @group_summaries.setter
    def group_summaries(self, group_summaries):
        """Sets the group_summaries of this ViewSummary.


        :param group_summaries: The group_summaries of this ViewSummary.  # noqa: E501
        :type: list[ViewSummary]
        """

        self._group_summaries = group_summaries

    @property
    def image(self):
        """Gets the image of this ViewSummary.  # noqa: E501


        :return: The image of this ViewSummary.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this ViewSummary.


        :param image: The image of this ViewSummary.  # noqa: E501
        :type: str
        """

        self._image = image

    @property
    def is_part_of_view(self):
        """Gets the is_part_of_view of this ViewSummary.  # noqa: E501


        :return: The is_part_of_view of this ViewSummary.  # noqa: E501
        :rtype: bool
        """
        return self._is_part_of_view

    @is_part_of_view.setter
    def is_part_of_view(self, is_part_of_view):
        """Sets the is_part_of_view of this ViewSummary.


        :param is_part_of_view: The is_part_of_view of this ViewSummary.  # noqa: E501
        :type: bool
        """

        self._is_part_of_view = is_part_of_view

    @property
    def bus_ob_id(self):
        """Gets the bus_ob_id of this ViewSummary.  # noqa: E501


        :return: The bus_ob_id of this ViewSummary.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_id

    @bus_ob_id.setter
    def bus_ob_id(self, bus_ob_id):
        """Sets the bus_ob_id of this ViewSummary.


        :param bus_ob_id: The bus_ob_id of this ViewSummary.  # noqa: E501
        :type: str
        """

        self._bus_ob_id = bus_ob_id

    @property
    def display_name(self):
        """Gets the display_name of this ViewSummary.  # noqa: E501


        :return: The display_name of this ViewSummary.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this ViewSummary.


        :param display_name: The display_name of this ViewSummary.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def group(self):
        """Gets the group of this ViewSummary.  # noqa: E501


        :return: The group of this ViewSummary.  # noqa: E501
        :rtype: bool
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this ViewSummary.


        :param group: The group of this ViewSummary.  # noqa: E501
        :type: bool
        """

        self._group = group

    @property
    def lookup(self):
        """Gets the lookup of this ViewSummary.  # noqa: E501


        :return: The lookup of this ViewSummary.  # noqa: E501
        :rtype: bool
        """
        return self._lookup

    @lookup.setter
    def lookup(self, lookup):
        """Sets the lookup of this ViewSummary.


        :param lookup: The lookup of this ViewSummary.  # noqa: E501
        :type: bool
        """

        self._lookup = lookup

    @property
    def major(self):
        """Gets the major of this ViewSummary.  # noqa: E501


        :return: The major of this ViewSummary.  # noqa: E501
        :rtype: bool
        """
        return self._major

    @major.setter
    def major(self, major):
        """Sets the major of this ViewSummary.


        :param major: The major of this ViewSummary.  # noqa: E501
        :type: bool
        """

        self._major = major

    @property
    def name(self):
        """Gets the name of this ViewSummary.  # noqa: E501


        :return: The name of this ViewSummary.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ViewSummary.


        :param name: The name of this ViewSummary.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def supporting(self):
        """Gets the supporting of this ViewSummary.  # noqa: E501


        :return: The supporting of this ViewSummary.  # noqa: E501
        :rtype: bool
        """
        return self._supporting

    @supporting.setter
    def supporting(self, supporting):
        """Sets the supporting of this ViewSummary.


        :param supporting: The supporting of this ViewSummary.  # noqa: E501
        :type: bool
        """

        self._supporting = supporting

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ViewSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ViewSummary):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class SearchResultsRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'association': 'str',
        'bus_ob_id': 'str',
        'custom_grid_def_id': 'str',
        'date_time_formatting': 'str',
        'field_id': 'str',
        'fields': 'list[str]',
        'filters': 'list[FilterInfo]',
        'include_all_fields': 'bool',
        'include_schema': 'bool',
        'page_number': 'int',
        'page_size': 'int',
        'scope': 'str',
        'scope_owner': 'str',
        'search_id': 'str',
        'search_name': 'str',
        'search_text': 'str',
        'sorting': 'list[SortInfo]',
        'prompt_values': 'list[PromptValue]'
    }

    attribute_map = {
        'association': 'association',
        'bus_ob_id': 'busObId',
        'custom_grid_def_id': 'customGridDefId',
        'date_time_formatting': 'dateTimeFormatting',
        'field_id': 'fieldId',
        'fields': 'fields',
        'filters': 'filters',
        'include_all_fields': 'includeAllFields',
        'include_schema': 'includeSchema',
        'page_number': 'pageNumber',
        'page_size': 'pageSize',
        'scope': 'scope',
        'scope_owner': 'scopeOwner',
        'search_id': 'searchId',
        'search_name': 'searchName',
        'search_text': 'searchText',
        'sorting': 'sorting',
        'prompt_values': 'promptValues'
    }

    def __init__(self, association=None, bus_ob_id=None, custom_grid_def_id=None, date_time_formatting=None, field_id=None, fields=None, filters=None, include_all_fields=None, include_schema=None, page_number=None, page_size=None, scope=None, scope_owner=None, search_id=None, search_name=None, search_text=None, sorting=None, prompt_values=None, local_vars_configuration=None):  # noqa: E501
        """SearchResultsRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._association = None
        self._bus_ob_id = None
        self._custom_grid_def_id = None
        self._date_time_formatting = None
        self._field_id = None
        self._fields = None
        self._filters = None
        self._include_all_fields = None
        self._include_schema = None
        self._page_number = None
        self._page_size = None
        self._scope = None
        self._scope_owner = None
        self._search_id = None
        self._search_name = None
        self._search_text = None
        self._sorting = None
        self._prompt_values = None
        self.discriminator = None

        if association is not None:
            self.association = association
        if bus_ob_id is not None:
            self.bus_ob_id = bus_ob_id
        if custom_grid_def_id is not None:
            self.custom_grid_def_id = custom_grid_def_id
        if date_time_formatting is not None:
            self.date_time_formatting = date_time_formatting
        if field_id is not None:
            self.field_id = field_id
        if fields is not None:
            self.fields = fields
        if filters is not None:
            self.filters = filters
        if include_all_fields is not None:
            self.include_all_fields = include_all_fields
        if include_schema is not None:
            self.include_schema = include_schema
        if page_number is not None:
            self.page_number = page_number
        if page_size is not None:
            self.page_size = page_size
        if scope is not None:
            self.scope = scope
        if scope_owner is not None:
            self.scope_owner = scope_owner
        if search_id is not None:
            self.search_id = search_id
        if search_name is not None:
            self.search_name = search_name
        if search_text is not None:
            self.search_text = search_text
        if sorting is not None:
            self.sorting = sorting
        if prompt_values is not None:
            self.prompt_values = prompt_values

    @property
    def association(self):
        """Gets the association of this SearchResultsRequest.  # noqa: E501


        :return: The association of this SearchResultsRequest.  # noqa: E501
        :rtype: str
        """
        return self._association

    @association.setter
    def association(self, association):
        """Sets the association of this SearchResultsRequest.


        :param association: The association of this SearchResultsRequest.  # noqa: E501
        :type: str
        """

        self._association = association

    @property
    def bus_ob_id(self):
        """Gets the bus_ob_id of this SearchResultsRequest.  # noqa: E501


        :return: The bus_ob_id of this SearchResultsRequest.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_id

    @bus_ob_id.setter
    def bus_ob_id(self, bus_ob_id):
        """Sets the bus_ob_id of this SearchResultsRequest.


        :param bus_ob_id: The bus_ob_id of this SearchResultsRequest.  # noqa: E501
        :type: str
        """

        self._bus_ob_id = bus_ob_id

    @property
    def custom_grid_def_id(self):
        """Gets the custom_grid_def_id of this SearchResultsRequest.  # noqa: E501


        :return: The custom_grid_def_id of this SearchResultsRequest.  # noqa: E501
        :rtype: str
        """
        return self._custom_grid_def_id

    @custom_grid_def_id.setter
    def custom_grid_def_id(self, custom_grid_def_id):
        """Sets the custom_grid_def_id of this SearchResultsRequest.


        :param custom_grid_def_id: The custom_grid_def_id of this SearchResultsRequest.  # noqa: E501
        :type: str
        """

        self._custom_grid_def_id = custom_grid_def_id

    @property
    def date_time_formatting(self):
        """Gets the date_time_formatting of this SearchResultsRequest.  # noqa: E501


        :return: The date_time_formatting of this SearchResultsRequest.  # noqa: E501
        :rtype: str
        """
        return self._date_time_formatting

    @date_time_formatting.setter
    def date_time_formatting(self, date_time_formatting):
        """Sets the date_time_formatting of this SearchResultsRequest.


        :param date_time_formatting: The date_time_formatting of this SearchResultsRequest.  # noqa: E501
        :type: str
        """

        self._date_time_formatting = date_time_formatting

    @property
    def field_id(self):
        """Gets the field_id of this SearchResultsRequest.  # noqa: E501


        :return: The field_id of this SearchResultsRequest.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this SearchResultsRequest.


        :param field_id: The field_id of this SearchResultsRequest.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def fields(self):
        """Gets the fields of this SearchResultsRequest.  # noqa: E501


        :return: The fields of this SearchResultsRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this SearchResultsRequest.


        :param fields: The fields of this SearchResultsRequest.  # noqa: E501
        :type: list[str]
        """

        self._fields = fields

    @property
    def filters(self):
        """Gets the filters of this SearchResultsRequest.  # noqa: E501


        :return: The filters of this SearchResultsRequest.  # noqa: E501
        :rtype: list[FilterInfo]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this SearchResultsRequest.


        :param filters: The filters of this SearchResultsRequest.  # noqa: E501
        :type: list[FilterInfo]
        """

        self._filters = filters

    @property
    def include_all_fields(self):
        """Gets the include_all_fields of this SearchResultsRequest.  # noqa: E501


        :return: The include_all_fields of this SearchResultsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_all_fields

    @include_all_fields.setter
    def include_all_fields(self, include_all_fields):
        """Sets the include_all_fields of this SearchResultsRequest.


        :param include_all_fields: The include_all_fields of this SearchResultsRequest.  # noqa: E501
        :type: bool
        """

        self._include_all_fields = include_all_fields

    @property
    def include_schema(self):
        """Gets the include_schema of this SearchResultsRequest.  # noqa: E501


        :return: The include_schema of this SearchResultsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_schema

    @include_schema.setter
    def include_schema(self, include_schema):
        """Sets the include_schema of this SearchResultsRequest.


        :param include_schema: The include_schema of this SearchResultsRequest.  # noqa: E501
        :type: bool
        """

        self._include_schema = include_schema

    @property
    def page_number(self):
        """Gets the page_number of this SearchResultsRequest.  # noqa: E501


        :return: The page_number of this SearchResultsRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this SearchResultsRequest.


        :param page_number: The page_number of this SearchResultsRequest.  # noqa: E501
        :type: int
        """

        self._page_number = page_number

    @property
    def page_size(self):
        """Gets the page_size of this SearchResultsRequest.  # noqa: E501


        :return: The page_size of this SearchResultsRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this SearchResultsRequest.


        :param page_size: The page_size of this SearchResultsRequest.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def scope(self):
        """Gets the scope of this SearchResultsRequest.  # noqa: E501


        :return: The scope of this SearchResultsRequest.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this SearchResultsRequest.


        :param scope: The scope of this SearchResultsRequest.  # noqa: E501
        :type: str
        """

        self._scope = scope

    @property
    def scope_owner(self):
        """Gets the scope_owner of this SearchResultsRequest.  # noqa: E501


        :return: The scope_owner of this SearchResultsRequest.  # noqa: E501
        :rtype: str
        """
        return self._scope_owner

    @scope_owner.setter
    def scope_owner(self, scope_owner):
        """Sets the scope_owner of this SearchResultsRequest.


        :param scope_owner: The scope_owner of this SearchResultsRequest.  # noqa: E501
        :type: str
        """

        self._scope_owner = scope_owner

    @property
    def search_id(self):
        """Gets the search_id of this SearchResultsRequest.  # noqa: E501


        :return: The search_id of this SearchResultsRequest.  # noqa: E501
        :rtype: str
        """
        return self._search_id

    @search_id.setter
    def search_id(self, search_id):
        """Sets the search_id of this SearchResultsRequest.


        :param search_id: The search_id of this SearchResultsRequest.  # noqa: E501
        :type: str
        """

        self._search_id = search_id

    @property
    def search_name(self):
        """Gets the search_name of this SearchResultsRequest.  # noqa: E501


        :return: The search_name of this SearchResultsRequest.  # noqa: E501
        :rtype: str
        """
        return self._search_name

    @search_name.setter
    def search_name(self, search_name):
        """Sets the search_name of this SearchResultsRequest.


        :param search_name: The search_name of this SearchResultsRequest.  # noqa: E501
        :type: str
        """

        self._search_name = search_name

    @property
    def search_text(self):
        """Gets the search_text of this SearchResultsRequest.  # noqa: E501


        :return: The search_text of this SearchResultsRequest.  # noqa: E501
        :rtype: str
        """
        return self._search_text

    @search_text.setter
    def search_text(self, search_text):
        """Sets the search_text of this SearchResultsRequest.


        :param search_text: The search_text of this SearchResultsRequest.  # noqa: E501
        :type: str
        """

        self._search_text = search_text

    @property
    def sorting(self):
        """Gets the sorting of this SearchResultsRequest.  # noqa: E501


        :return: The sorting of this SearchResultsRequest.  # noqa: E501
        :rtype: list[SortInfo]
        """
        return self._sorting

    @sorting.setter
    def sorting(self, sorting):
        """Sets the sorting of this SearchResultsRequest.


        :param sorting: The sorting of this SearchResultsRequest.  # noqa: E501
        :type: list[SortInfo]
        """

        self._sorting = sorting

    @property
    def prompt_values(self):
        """Gets the prompt_values of this SearchResultsRequest.  # noqa: E501


        :return: The prompt_values of this SearchResultsRequest.  # noqa: E501
        :rtype: list[PromptValue]
        """
        return self._prompt_values

    @prompt_values.setter
    def prompt_values(self, prompt_values):
        """Sets the prompt_values of this SearchResultsRequest.


        :param prompt_values: The prompt_values of this SearchResultsRequest.  # noqa: E501
        :type: list[PromptValue]
        """

        self._prompt_values = prompt_values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchResultsRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchResultsRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class RemoveItemFromQueueRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bus_ob_id': 'str',
        'bus_ob_rec_id': 'str',
        'history_notes': 'str',
        'queue_stand_in_key': 'str'
    }

    attribute_map = {
        'bus_ob_id': 'busObId',
        'bus_ob_rec_id': 'busObRecId',
        'history_notes': 'historyNotes',
        'queue_stand_in_key': 'queueStandInKey'
    }

    def __init__(self, bus_ob_id=None, bus_ob_rec_id=None, history_notes=None, queue_stand_in_key=None, local_vars_configuration=None):  # noqa: E501
        """RemoveItemFromQueueRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bus_ob_id = None
        self._bus_ob_rec_id = None
        self._history_notes = None
        self._queue_stand_in_key = None
        self.discriminator = None

        if bus_ob_id is not None:
            self.bus_ob_id = bus_ob_id
        if bus_ob_rec_id is not None:
            self.bus_ob_rec_id = bus_ob_rec_id
        if history_notes is not None:
            self.history_notes = history_notes
        if queue_stand_in_key is not None:
            self.queue_stand_in_key = queue_stand_in_key

    @property
    def bus_ob_id(self):
        """Gets the bus_ob_id of this RemoveItemFromQueueRequest.  # noqa: E501


        :return: The bus_ob_id of this RemoveItemFromQueueRequest.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_id

    @bus_ob_id.setter
    def bus_ob_id(self, bus_ob_id):
        """Sets the bus_ob_id of this RemoveItemFromQueueRequest.


        :param bus_ob_id: The bus_ob_id of this RemoveItemFromQueueRequest.  # noqa: E501
        :type: str
        """

        self._bus_ob_id = bus_ob_id

    @property
    def bus_ob_rec_id(self):
        """Gets the bus_ob_rec_id of this RemoveItemFromQueueRequest.  # noqa: E501


        :return: The bus_ob_rec_id of this RemoveItemFromQueueRequest.  # noqa: E501
        :rtype: str
        """
        return self._bus_ob_rec_id

    @bus_ob_rec_id.setter
    def bus_ob_rec_id(self, bus_ob_rec_id):
        """Sets the bus_ob_rec_id of this RemoveItemFromQueueRequest.


        :param bus_ob_rec_id: The bus_ob_rec_id of this RemoveItemFromQueueRequest.  # noqa: E501
        :type: str
        """

        self._bus_ob_rec_id = bus_ob_rec_id

    @property
    def history_notes(self):
        """Gets the history_notes of this RemoveItemFromQueueRequest.  # noqa: E501


        :return: The history_notes of this RemoveItemFromQueueRequest.  # noqa: E501
        :rtype: str
        """
        return self._history_notes

    @history_notes.setter
    def history_notes(self, history_notes):
        """Sets the history_notes of this RemoveItemFromQueueRequest.


        :param history_notes: The history_notes of this RemoveItemFromQueueRequest.  # noqa: E501
        :type: str
        """

        self._history_notes = history_notes

    @property
    def queue_stand_in_key(self):
        """Gets the queue_stand_in_key of this RemoveItemFromQueueRequest.  # noqa: E501


        :return: The queue_stand_in_key of this RemoveItemFromQueueRequest.  # noqa: E501
        :rtype: str
        """
        return self._queue_stand_in_key

    @queue_stand_in_key.setter
    def queue_stand_in_key(self, queue_stand_in_key):
        """Sets the queue_stand_in_key of this RemoveItemFromQueueRequest.


        :param queue_stand_in_key: The queue_stand_in_key of this RemoveItemFromQueueRequest.  # noqa: E501
        :type: str
        """

        self._queue_stand_in_key = queue_stand_in_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoveItemFromQueueRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RemoveItemFromQueueRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class SaveTeamMemberRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'is_team_manager': 'bool',
        'set_as_default_team': 'bool',
        'team_id': 'str',
        'user_rec_id': 'str'
    }

    attribute_map = {
        'is_team_manager': 'isTeamManager',
        'set_as_default_team': 'setAsDefaultTeam',
        'team_id': 'teamId',
        'user_rec_id': 'userRecId'
    }

    def __init__(self, is_team_manager=None, set_as_default_team=None, team_id=None, user_rec_id=None, local_vars_configuration=None):  # noqa: E501
        """SaveTeamMemberRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._is_team_manager = None
        self._set_as_default_team = None
        self._team_id = None
        self._user_rec_id = None
        self.discriminator = None

        if is_team_manager is not None:
            self.is_team_manager = is_team_manager
        if set_as_default_team is not None:
            self.set_as_default_team = set_as_default_team
        if team_id is not None:
            self.team_id = team_id
        if user_rec_id is not None:
            self.user_rec_id = user_rec_id

    @property
    def is_team_manager(self):
        """Gets the is_team_manager of this SaveTeamMemberRequest.  # noqa: E501


        :return: The is_team_manager of this SaveTeamMemberRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_team_manager

    @is_team_manager.setter
    def is_team_manager(self, is_team_manager):
        """Sets the is_team_manager of this SaveTeamMemberRequest.


        :param is_team_manager: The is_team_manager of this SaveTeamMemberRequest.  # noqa: E501
        :type: bool
        """

        self._is_team_manager = is_team_manager

    @property
    def set_as_default_team(self):
        """Gets the set_as_default_team of this SaveTeamMemberRequest.  # noqa: E501


        :return: The set_as_default_team of this SaveTeamMemberRequest.  # noqa: E501
        :rtype: bool
        """
        return self._set_as_default_team

    @set_as_default_team.setter
    def set_as_default_team(self, set_as_default_team):
        """Sets the set_as_default_team of this SaveTeamMemberRequest.


        :param set_as_default_team: The set_as_default_team of this SaveTeamMemberRequest.  # noqa: E501
        :type: bool
        """

        self._set_as_default_team = set_as_default_team

    @property
    def team_id(self):
        """Gets the team_id of this SaveTeamMemberRequest.  # noqa: E501


        :return: The team_id of this SaveTeamMemberRequest.  # noqa: E501
        :rtype: str
        """
        return self._team_id

    @team_id.setter
    def team_id(self, team_id):
        """Sets the team_id of this SaveTeamMemberRequest.


        :param team_id: The team_id of this SaveTeamMemberRequest.  # noqa: E501
        :type: str
        """

        self._team_id = team_id

    @property
    def user_rec_id(self):
        """Gets the user_rec_id of this SaveTeamMemberRequest.  # noqa: E501


        :return: The user_rec_id of this SaveTeamMemberRequest.  # noqa: E501
        :rtype: str
        """
        return self._user_rec_id

    @user_rec_id.setter
    def user_rec_id(self, user_rec_id):
        """Sets the user_rec_id of this SaveTeamMemberRequest.


        :param user_rec_id: The user_rec_id of this SaveTeamMemberRequest.  # noqa: E501
        :type: str
        """

        self._user_rec_id = user_rec_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SaveTeamMemberRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SaveTeamMemberRequest):
            return True

        return self.to_dict() != other.to_dict()
